==> org.eclipse.gyrex.monitoring.source_1.0.0.v20120423-0944.jar: org/eclipse/gyrex/monitoring/internal/MonitoringActivator.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2010 Gunnar Wagenknecht and others.
 * All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 which accompanies this distribution,
 * and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Contributors:
 *     Gunnar Wagenknecht - initial API and implementation
 *******************************************************************************/
package org.eclipse.gyrex.monitoring.internal;

import org.eclipse.gyrex.common.runtime.BaseBundleActivator;

import org.osgi.framework.BundleContext;

public class MonitoringActivator extends BaseBundleActivator {

	/** plug-in id */
	public static final String SYMBOLIC_NAME = "org.eclipse.gyrex.monitoring";

	private MetricSetTracker metricSetTracker;
	private StatusTracker statusTracker;

	/**
	 * Creates a new instance.
	 */
	public MonitoringActivator() {
		super(SYMBOLIC_NAME);
	}

	@Override
	protected void doStart(final BundleContext context) throws Exception {
		// track metrics
		metricSetTracker = new MetricSetTracker(context);
		metricSetTracker.open();

		// track status
		statusTracker = new StatusTracker(context);
		statusTracker.open();
	}

	@Override
	protected void doStop(final BundleContext context) throws Exception {
		metricSetTracker.close();
		metricSetTracker = null;

		statusTracker.close();
		statusTracker = null;
	}
}

==> org.eclipse.gyrex.monitoring.source_1.2.0.v20140411-0938.jar: org/eclipse/gyrex/monitoring/internal/MonitoringActivator.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2013 Gunnar Wagenknecht and others.
 * All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 which accompanies this distribution,
 * and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Contributors:
 *     Gunnar Wagenknecht - initial API and implementation
 *******************************************************************************/
package org.eclipse.gyrex.monitoring.internal;

import org.eclipse.gyrex.common.runtime.BaseBundleActivator;

import org.osgi.framework.BundleContext;

public class MonitoringActivator extends BaseBundleActivator {

	/** plug-in id */
	public static final String SYMBOLIC_NAME = "org.eclipse.gyrex.monitoring";

	private MetricSetTracker metricSetTracker;
	private StatusTrackerWithMetric statusTracker;

	/**
	 * Creates a new instance.
	 */
	public MonitoringActivator() {
		super(SYMBOLIC_NAME);
	}

	@Override
	protected void doStart(final BundleContext context) throws Exception {
		// track metrics
		metricSetTracker = new MetricSetTracker(context);
		metricSetTracker.open();

		// track status
		statusTracker = new StatusTrackerWithMetric(context);
		statusTracker.open();
	}

	@Override
	protected void doStop(final BundleContext context) throws Exception {
		metricSetTracker.close();
		metricSetTracker = null;

		statusTracker.close();
		statusTracker = null;
	}
}
